@@ -1,3 +1,5 @@
+from __future__ import absolute_import, division
+
 import sqlalchemy
 from sqlalchemy.engine import RowProxy
 from sqlalchemy.exc import StatementError
@@ -10,16 +12,17 @@ from alchimia.engine import (
     TwistedEngine, TwistedConnection, TwistedTransaction,
 )
 
-from .doubles import FakeThreadedReactor
+from .doubles import FakeThreadedReactor, ImmediateWorker
 
 
 def create_engine():
     return sqlalchemy.create_engine(
-        "sqlite://", strategy=TWISTED_STRATEGY, reactor=FakeThreadedReactor()
+        "sqlite://", strategy=TWISTED_STRATEGY, reactor=FakeThreadedReactor(),
+        create_worker=ImmediateWorker,
     )
 
 
-class TestEngineCreation(object):
+class TestEngineCreation(unittest.TestCase):
     def test_simple_create_engine(self):
         engine = sqlalchemy.create_engine(
             "sqlite://",
